<?php
/**
 * @package     CSVI
 * @subpackage  HikaShop
 *
 * @author      Roland Dalmulder <contact@csvimproved.com>
 * @copyright   Copyright (C) 2006 - @year@ RolandD Cyber Produksi. All rights reserved.
 * @license     GNU/GPLv3 http://www.gnu.org/licenses/gpl-3.0.html
 * @link        http://www.csvimproved.com
 */

defined('_JEXEC') or die;

/**
 * HikaShop File table.
 *
 * @package     CSVI
 * @subpackage  HikaShop
 * @since       6.0
 */
class HikashopTableFile extends CsviTableDefault
{
	/**
	 * Table constructor.
	 *
	 * @param   string     $table   Name of the database table to model.
	 * @param   string     $key     Name of the primary key field in the table.
	 * @param   JDatabase  &$db     Database driver
	 * @param   array      $config  The configuration parameters array
	 *
	 * @since   4.0
	 */
	public function __construct($table, $key, &$db, $config = array())
	{
		parent::__construct('#__hikashop_file', 'file_id', $db, $config);
	}

	/**
	 * Check if a media file already exists.
	 *
	 * @return  bool  True if media exists | False if media does not exist.
	 *
	 * @since   4.0
	 */
	public function check()
	{
		$query = $this->db->getQuery(true)
			->select($this->db->quoteName($this->_tbl_key))
			->from($this->db->quoteName($this->_tbl))
			->where($this->db->quoteName('file_path') . ' = ' . $this->db->quote($this->file_path))
			->where($this->db->quoteName('file_type') . ' = ' . $this->db->quote($this->file_type));
		$this->db->setQuery($query);
		$id = $this->db->loadResult();

		$this->log->add('Checking if the file_url exists');

		if ($id > 0)
		{
			$this->file_id = $id;

			return true;
		}

		return false;
	}

	/**
	 * Reset the primary key.
	 *
	 * @return  bool  Returns true on success.
	 *
	 * @since   6.0
	 */
	public function reset()
	{
		parent::reset();

		// Empty the primary key
		$this->set('file_id', null);

		return true;
	}
}
